@@ -70,6 +70,30 @@ VALIDATE_TASK_SCHEMA = '''{
                                     },
                                     "type": "object"
                                 },
+                                "cargo_features": {
+                                    "default": [],
+                                    "items": {
+                                        "maxLength": 256,
+                                        "minLength": 1,
+                                        "type": "string"
+                                    },
+                                    "maxItems": 1000,
+                                    "minItems": 0,
+                                    "type": "array",
+                                    "uniqueItems": true
+                                },
+                                "cargo_restrictions": {
+                                    "default": [],
+                                    "items": {
+                                        "maxLength": 256,
+                                        "minLength": 1,
+                                        "type": "string"
+                                    },
+                                    "maxItems": 1000,
+                                    "minItems": 0,
+                                    "type": "array",
+                                    "uniqueItems": true
+                                },
                                 "height": {
                                     "default": 0,
                                     "format": "double",
@@ -183,7 +207,7 @@ VALIDATE_TASK_SCHEMA = '''{
                                 "type": "object"
                             },
                             "reward": {
-                                "default": 1000,
+                                "default": 1000.1,
                                 "format": "double",
                                 "maximum": 1000000,
                                 "minimum": 0,
